@@ -477,7 +477,7 @@ FORTRAN_SUBR ( CCHMOD, cchmod,
 int __stdcall ISATTY (int *lunit)
 {
   lunit = 0 ;
-  return lunit;
+  return *lunit;
 }
 
 /* erfc doesnt seem to be in Mircrosoft Visual Studdio so this is a fudge */
@@ -491,7 +491,7 @@ float __stdcall ERFC(float *value)
 int isatty_ (int *lunit)
 {
   lunit = 0 ;
-  return lunit;
+  return *lunit;
 }
 
 float erfc_ (float *value)
